(define-module (ui ldap-users ajax)
    :use-module (alterator woo)
    :use-module (alterator ajax)
    :export (init))

(define (update-users . data)
    (let ((user (if (pair? data) (car data) (form-value "user"))))
    (form-update-value "username" user)
    (form-update-value-list 
      '("sn" "givenname" "patronym" "homedirectory" "loginshell" "o" "title" "telephonenumber" "mobile") 
      (woo-read-first "/ldap-users" 'user user))
    (update-mail-list)))
    

(define (update-mail-list)
    (let ((user (form-value "user")))
    (form-update-value "newemail" "")
    (form-update-enum "email" (woo-list "/ldap-users/avail_emails" 'user user))))

(define (ui-init . data)
    (form-update-value "newusername" "")
    (form-update-value "username" "")
    (form-update-value "sn" "")
    (form-update-value "givenname" "")
    (form-update-value "patronym" "")
    (form-update-value "homedirectory" "")
    (form-update-value "o" "")
    (form-update-value "title" "")
    (form-update-value "mobile" "")
    (form-update-value "telephonenumber" "")
    (ui-reset-password)
    (form-update-enum "email" (woo-list "/ldap-users/avail_emails" 'user ""))
    (form-update-enum "user" (woo-list "/ldap-users/avail_users"))
    )

(define (ui-usersave)
    (let ((user (form-value "user")))
    (if  (not (boolean? user))
      (catch/message
        (lambda()
        (apply woo-write "/ldap-users"
		 (form-value-list
		   '("user" "language" "homedirectory" "sn" "givenname" "patronym" "loginshell"
             "o" "telephonenumber" "mobile" "title"
		     "passwd_1" "passwd_2" "passwd_auto" "auto")))
        (ui-init))))))

(define (ui-userdel)
    (let ((user (form-value "user")))
      (if  (not (boolean? user))
      (catch/message
        (lambda()
        (woo-delete "/ldap-users" 'user user 'language (form-value "language"))
        (ui-init))))))

(define (ui-useradd)
    (let ((newusername (form-value "newusername")))
      (catch/message
        (lambda()
        (woo-new "/ldap-users" 'newusername newusername 'language (form-value "language"))
        (ui-init newusername)))))

(define (ui-emailadd)
    (let ((user (form-value "user"))
          (newemail (form-value "newemail")))
    (cond ((and (not (boolean? user)) (not (boolean? newemail)))
    (woo "emailadd" "/ldap-users" 'user user 'newemail newemail)
    (update-mail-list)))))


(define (ui-emaildel)
    (let ((user (form-value "user"))
          (email (form-value "email")))
    (cond ((and (not (boolean? user)) (not (boolean? email)))
    (woo "emaildel" "/ldap-users" 'user user 'email email)
    (update-mail-list)))))

(define (ui-generate)
  (form-update-value-list
    '("passwd_auto")
    (car (woo "generate" "/ldap-users"))))

(define (ui-auto . auto)
  (let ((auto (if (pair? auto) (car auto) (form-value "auto"))))
    (form-update-visibility
      '("passwd_auto" "generate_button")
      auto)
    (form-update-visibility
      '("passwd_1" "passwd_2" "lpasswd_1" "lpasswd_2")
      (not auto))))

(define (ui-reset-password)
  (form-update-value-list
    '("passwd_1" "passwd_2" "lpasswd_1" "lpasswd_2")
    '("/ldap-users" 'a "b")) ;;empty command
  (form-update-value "auto" #f)
  (ui-auto #f)
  (ui-generate))

(define (init)
    (ui-init)
    (form-bind "auto" "change" ui-auto)
    (form-bind "generate_button" "click" ui-generate)
    (form-bind "emailadd" "click" ui-emailadd)
    (form-bind "emaildel" "click" ui-emaildel)
    (form-bind "usersave" "click" ui-usersave)
    (form-bind "useradd" "click" ui-useradd)
    (form-bind "userdelete" "click" ui-userdel)
    (form-bind "user" "change" update-users))

